/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */

 




package org.greenstone.gatherer.gui;

import javax.swing.JTextArea;

public class GTextArea
	 extends JTextArea {
	 
	 boolean tab_action                               = true;

	 static final public boolean INSERT_TAB_CHARACTER = true;
	 static final public boolean FOCUS_NEXT_COMPONENT = false;

	 /** Default constructor that simply calls superclass constructor.
	  * @param content A String specifying the initial content of this text
	  * component.
	  */
	 public GTextArea(String content) {
		  super(content);
	 }

	 /** Constructor which also takes an argument specifying how this TextArea 
	  * should respond to tab key presses.
	  * @param content A String specifying the initial content of this text
	  * component.
	  * @param tab_action A Boolean indicating the desired tab effect.
	  */
	 public GTextArea(String content, boolean tab_action) {
		  super(content);
		  this.tab_action = tab_action;
	 }

	 /** Called to determine whether this TextArea is handling tab presses 
	  * internally (INSERT_TAB_CHARACTER) or whether the focus manager should
	  * handle them (FOCUS_NEXT_COMPONENT).
	  * @return A Boolean indicating if the tab key presses are being managed
	  * internally, ie should tab traversal be disabled.
	  * @deprecated
	  */
	 /** public boolean isManagingFocus() {
		  return tab_action;
		  }
	 */

	 /** Sets how the TextArea should respond to tab key presses.
	  * @param tab_action A Boolean indicating the desired tab effect.
	  */
	 public void setTabAction(boolean tab_action) {
		  this.tab_action = tab_action;
	 }
}




